Expr

Struct Expr 

pub struct Expr(Box<Expression>);
A Substrait expression carried as an extension argument or output column.

Boxed because proto::Expression is large (multiple Vec fields in variants like ScalarFunction).

Tuple Fields

0: Box<Expression>

Implementations

Source

impl Expr

pub fn as_proto(&self) -> &Expression

Borrow the underlying Substrait expression protobuf.

pub fn to_proto(&self) -> Expression

Clone the underlying Substrait expression protobuf.

pub fn as_direct_reference(&self) -> Option<Reference>

If this expression is a direct field reference ($N), return it.