ExtensionArgs

Struct ExtensionArgs 

pub struct ExtensionArgs {
    pub positional: Vec<ExtensionValue>,
    pub named: IndexMap<String, ExtensionValue>,
    pub output_columns: Vec<ExtensionColumn>,
    pub relation_type: ExtensionRelationType,
}
Represents the arguments and output columns for an extension relation.

Named arguments are stored in an IndexMap whose iteration order determines display order. Extension [Explainable::to_args()] implementations should insert named arguments in the order they should appear in the text format.

Fields

positional: Vec<ExtensionValue>

Positional arguments (expressions, literals, references)

named: IndexMap<String, ExtensionValue>

Named arguments, displayed in the order they were inserted

output_columns: Vec<ExtensionColumn>

Output columns (named columns, references, or expressions)

relation_type: ExtensionRelationType

The type of extension relation (Leaf/Single/Multi)

Implementations

Source

impl ExtensionArgs

pub fn new(relation_type: ExtensionRelationType) -> Self

Create a new empty ExtensionArgs

pub fn extractor(&self) -> ArgsExtractor<'_>

Create an extractor for validating named arguments