pub enum ExtensionValue {
String(String),
Integer(i64),
Float(f64),
Boolean(bool),
Expr(Expr),
Enum(String),
Tuple(TupleValue),
}Expand description
Represents a value in extension arguments.
These values are the structured form of text-format extension arguments, fully resolved - i.e. any additional context (such as function anchors etc) are part of this struct itself.
Variants
String(String)
Untyped literals. These are not input or output with types (e.g. 2,
not 2:i64), and suitable for protobuf extension fields that are not
substrait types.
Integer(i64)
Float(f64)
Boolean(bool)
Expr(Expr)
Substrait expression value, including typed literals and field references.
Use TryFrom<&ExtensionValue> for Expr when a handler accepts either an
expression or a scalar value widened into an expression.
Enum(String)
Enum value (e.g. &CORE, &Inner) — the string holds the identifier
without the & prefix
Tuple(TupleValue)
Tuple of values, e.g. (&HASH, &RANGE) or (42, ‘hello’)
Implementations
Sourceimpl ExtensionValue
impl ExtensionValue
Sourcepub fn kind(&self) -> ExtensionValueKind
pub fn kind(&self) -> ExtensionValueKind
Return the variant kind of this value for structured diagnostics.