pub struct Expr(Box<Expression>);Expand description
A Substrait expression carried as an extension argument or output column.
Boxed because proto::Expression is large (multiple Vec fields in
variants like ScalarFunction).
Tuple Fields
0: Box<Expression>Implementations
Sourceimpl Expr
impl Expr
Sourcepub fn as_proto(&self) -> &Expression
pub fn as_proto(&self) -> &Expression
Borrow the underlying Substrait expression protobuf.
Sourcepub fn to_proto(&self) -> Expression
pub fn to_proto(&self) -> Expression
Clone the underlying Substrait expression protobuf.
Sourcepub fn as_direct_reference(&self) -> Option<Reference>
pub fn as_direct_reference(&self) -> Option<Reference>
If this expression is a direct field reference ($N), return it.